# pusteblume

[![](https://github.com/PascalinDe/pusteblume/workflows/Python/badge.svg)](https://github.com/PascalinDe/pusteblume/actions)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
